#!/usr/bin/env bash

set -e

shopt -s dotglob
[ "${DEBUG:-}" == 'true' ] && set -x

main ()
{
    artifacts_link=$(curl http://files.gameap.ru/fivem/latest-linux-artifacts)

    if ! curl -O "${artifacts_link}"; then
        echo 'Unable to download artifacts' >> /dev/stderr
        exit 1
    fi

    if ! tar -xf fx.tar.xz; then
        echo 'Unable to unpack artifacts' >> /dev/stderr
        exit 1
    fi

    rm fx.tar.xz

    if ! curl -OL 'https://github.com/citizenfx/cfx-server-data/archive/master.zip'; then
        echo 'Unable to download cfx-server-data' >> /dev/stderr
        exit 1
    fi

    if ! unzip -oq master.zip -d ./ ; then
        echo 'Unable to unzip cfx-server-data' >> /dev/stderr
        exit 1
    fi

    rm master.zip

    rsync -av --remove-source-files cfx-server-data-master/* ./
    rm -r cfx-server-data-master
}

__dir="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
cd $__dir;

echo "Current path: ${__dir}"

main